@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.0801';
 
 use Bit::Vector;
 use DBI;
@@ -201,9 +201,9 @@ sub power {
 
 sub score {
     my $self = shift;
-    my ( $open_sparator, $close_separator ) = @_;
+    my ( $open_separator, $close_separator ) = @_;
 
-    my $parts = $self->score_parts( $open_sparator, $close_separator );
+    my $parts = $self->score_parts( $open_separator, $close_separator );
 
     for my $mask ( keys %$parts ) {
         for my $element ( @{ $parts->{$mask} } ) {
@@ -249,7 +249,7 @@ sub _familiarity {
 
 sub score_parts {
     my $self = shift;
-    my ( $open_sparator, $close_separator, $line_terminator ) = @_;
+    my ( $open_separator, $close_separator, $line_terminator ) = @_;
 
     $line_terminator = '' unless defined $line_terminator;
 
@@ -278,7 +278,7 @@ sub score_parts {
             $count{unknownc} += $unknownc;
         }
 
-        my ( $s, $m ) = _reconstruct( $self->{word}, $c, $open_sparator, $close_separator );
+        my ( $s, $m ) = _reconstruct( $self->{word}, $c, $open_separator, $close_separator );
 
         my $defn = [];
         for my $i ( @$m )
@@ -289,8 +289,12 @@ sub score_parts {
             }
         }
 
-        push @{ $self->{score_parts}{$together} },
-            { score => \%count, partition => $s, definition => $defn };
+        push @{ $self->{score_parts}{$together} }, {
+            score       => \%count,
+            partition   => $s,
+            definition  => $defn,
+            familiarity => $self->_familiarity($together),
+        };
     }
 
     return $self->{score_parts};
@@ -412,7 +416,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.08
+version 0.0801
 
 =head1 SYNOPSIS
 
@@ -495,7 +499,7 @@ all masks.
 =head2 score()
 
   $score = $p->score();
-  $score = $p->score( $open_sparator, $close_separator);
+  $score = $p->score( $open_separator, $close_separator);
 
 Score the known vs unknown word part combinations into ratios of characters and
 chunks or parts or "spans of adjacent characters" B<as a collection of strings>.
@@ -507,19 +511,19 @@ This method sets the B<score> member to a list of hashrefs with keys:
   score
   familiarity
 
-If not given, the B<$open_sparator> and B<$close_separator> are '<' and '>' by
+If not given, the B<$open_separator> and B<$close_separator> are '<' and '>' by
 default.
 
 =head2 score_parts()
 
   $score_parts = $p->score_parts();
-  $score_parts = $p->score_parts( $open_sparator, $close_separator );
-  $score_parts = $p->score_parts( $open_sparator, $close_separator, $line_terminator );
+  $score_parts = $p->score_parts( $open_separator, $close_separator );
+  $score_parts = $p->score_parts( $open_separator, $close_separator, $line_terminator );
 
 Score the known vs unknown word part combinations into ratios of characters and
 chunks (spans of adjacent characters).
 
-If not given, the B<$open_sparator> and B<$close_separator> are '<' and '>' by
+If not given, the B<$open_separator> and B<$close_separator> are '<' and '>' by
 default.
 
 The B<$line_terminator> can be any string, like a newline (C<\n> or an HTML
